package com.robinj.omgubuntu;

import java.util.ArrayList;
import java.util.List;

import android.net.Uri;
import android.os.Bundle;
import android.os.Handler;
import android.annotation.SuppressLint;
import android.app.Activity;
import android.app.AlertDialog;
import android.app.Notification;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.view.Menu;
import android.view.View;
import android.webkit.WebChromeClient;
import android.webkit.WebView;
import android.widget.Toast;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import org.w3c.dom.Document;
import org.w3c.dom.NodeList;
import org.w3c.dom.Node;

public class MainActivity extends Activity
{
	String			newLine		= System.getProperty ("line.separator");
	List<String[]>	lastData;
	Handler			jsHandler	= new Handler ();
	
	@SuppressLint("SetJavaScriptEnabled")
	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate (savedInstanceState);
		setContentView (R.layout.activity_main);
		
		WebView web = (WebView) findViewById (R.id.web);
		web.getSettings ().setJavaScriptEnabled (true);
		web.setWebChromeClient (new WebChromeClient ());
		JavaScriptInterface jsInterface = new JavaScriptInterface (this);
		web.addJavascriptInterface (jsInterface, "android");
	}
	
	@Override
	public boolean onCreateOptionsMenu(Menu menu)
	{
		getMenuInflater ().inflate (R.menu.activity_main, menu);
		return true;
	}
	
	public void showDialog(String message)
	{
		AlertDialog dlg = new AlertDialog.Builder (this).create ();
		dlg.setMessage (message);
		dlg.setButton ("OK", new DialogInterface.OnClickListener ()
		{
			public void onClick (DialogInterface dialog, int which)
			{
				dialog.dismiss ();
			}
		});
		dlg.show ();
	}
	
	public void logo_clicked(View view)
	{
		Intent browserIntent = new Intent (Intent.ACTION_VIEW,
				Uri.parse ("http://www.omgubuntu.co.uk/"));
		startActivity (browserIntent);
	}
	
	public void btnRefresh_clicked(View view)
	{
		try
		{
			WebView web = (WebView) findViewById (R.id.web);
			List<String[]> data = getArticles ();
			
			String css = "html, body { background: white; color: black; font-family: \"Ubuntu\", \"Droid Sans\"; margin: 0px; padding: 0px 2px 0px 2px; }"
					+ "div.item { margin: 2px 0px 2px 0px; }"
					+ "a { color: black; text-decoration: none; font-weight: bold; }"
					+ "span.title { font-size: 16px; }"
					+ "span.date { color: #888888; font-size: 10px; font-weight: normal; }"
					+ "hr { background-color: #ABABAB; height: 0px; }";
			
			String js = "";
			
			String html = "<html>"
					+ "<head>"
					+ "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />"
					+ "<style type=\"text/css\">" + css + "</style>"
					+ (js != "" ? "<script type=\"text/javascript\">" + js + "</script>" : "")
					+ "</head>" + "<body>";
			
			for (int i = 0; i < data.size (); i++)
			{
				html += (i < 1 ? "" : "<hr />") + "<div class=\"item\" id=\"item-" + i + "\">"
						+ "<a onClick=\"android.showArticle (" + i + ");\" href=\"#\">"
						+ "<span class=\"title\">"
						+ data.get (i)[0]
						+ "</span></a><br />"
						+ "<a onClick=\"android.showArticle (" + i + ");\" href=\"#\">"
						+ "<span class=\"date\">" + data.get (i)[2]
						+ "</span><a /><br />";
			}
			
			html += "</body>" + "</html>";
			
			web.clearView ();
			web.loadData (html, "text/html", null);
			
			if (!data.equals (lastData))
			{
				showNotification ("OMG! New articles!", "OMG! Ubuntu!",
						"OMG! New Articles!");
				lastData = data;
			}
		} catch (Exception ex)
		{
			showDialog ("Error!" + newLine + newLine + ex.getMessage ());
		}
	}
	
	public void showNotification(CharSequence ticker, CharSequence title,
			CharSequence message)
	{
		String notificationService = Context.NOTIFICATION_SERVICE;
		NotificationManager notificationManager = (NotificationManager) getSystemService (notificationService);
		
		int icon = R.drawable.ic_launcher;
		long time = System.currentTimeMillis ();
		
		Notification notification = new Notification (icon, ticker, time);
		
		Context context = getApplicationContext ();
		Intent notificationIntent = new Intent (this, MainActivity.class);
		PendingIntent contentIntent = PendingIntent.getActivity (this, 0,
				notificationIntent, 0);
		
		notification
				.setLatestEventInfo (context, title, message, contentIntent);
		
		int notificationId = 1;
		notificationManager.notify (notificationId, notification);
	}
	
	public List<String[]> getArticles()
	{
		List<String[]> data = new ArrayList<String[]> ();
		
		try
		{
			DocumentBuilderFactory dbFactory = DocumentBuilderFactory
					.newInstance ();
			DocumentBuilder dBuilder = dbFactory.newDocumentBuilder ();
			Document doc = dBuilder
					.parse ("http://feeds.feedburner.com/d0od?format=xml");
			doc.getDocumentElement ().normalize ();
			
			NodeList items = doc.getElementsByTagName ("item");
			
			for (int i = 0; i < items.getLength (); i++)
			{
				Node item = items.item (i);
				
				if (item.getNodeType () == Node.ELEMENT_NODE)
				{
					NodeList tags = item.getChildNodes ();
					
					String title = null;
					String link = null;
					String date = null;
					String content = null;
					
					for (int j = 0; j < tags.getLength (); j++)
					{
						Node tag = tags.item (j);
						
						if (tag.getNodeName ().equals ("title"))
							title = tag.getTextContent ();
						else if (tag.getNodeName ().equals ("link"))
							link = tag.getTextContent ();
						else if (tag.getNodeName ().equals ("pubDate"))
							date = tag.getTextContent ();
						else if (tag.getNodeName ().equals ("content"))
							content = tag.getTextContent ();
					}
					
					String[] article = { title, link, date, content };
					data.add (article);
				}
			}
		} catch (Exception ex)
		{
			showDialog ("Aie caramba!" + newLine + newLine + ex.getMessage ());
		}
		
		return data;
	}
	
	public class JavaScriptInterface
	{
		Context	mContext;
		
		JavaScriptInterface (Context c)
		{
			mContext = c;
		}
		
		public void showToast (String toast)
		{
			Toast.makeText (mContext, toast, Toast.LENGTH_SHORT).show ();
		}
		
		public void showArticle (int id)
		{
			//TODO//
		}
	}
}
